markuptools.remove_markup_from_leaves_in_expr
=============================================

.. autofunction:: abjad.tools.markuptools.remove_markup_from_leaves_in_expr.remove_markup_from_leaves_in_expr
